# AtomicMixer RefundTool

## Installation

```
python3 -m venv venv
. venv/bin/activate
pip install atomicmixer
atomicmixer
```

## Donations

**I do not accept donations. If you have some sats left donate them to the [Torproject](https://donate.torproject.org/cryptocurrency/) or to the [EFF](https://supporters.eff.org/donate/join-eff-4).**
